@@ -72,6 +72,7 @@ import com.openexchange.ajax.fields.ResponseFields;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.exception.OXException;
 import com.openexchange.groupware.contexts.Context;
+import com.openexchange.java.StringAllocator;
 import com.openexchange.multiple.MultipleHandler;
 import com.openexchange.publish.Publication;
 import com.openexchange.publish.PublicationErrorMessage;
@@ -309,33 +310,34 @@ public class PublicationMultipleHandler implements MultipleHandler {
 
     private String getURLPrefix(final JSONObject request, final Publication publication) {
         String hostname = Hostname.getInstance().getHostname(publication);
-        final String serverURL = request.optString("__serverURL");
+        String serverURL = request.optString("__serverURL");
         String protocol = "https://";
-        if(hostname != null) {
-            if(serverURL == null || serverURL.startsWith("https")) {
+
+        if (hostname != null) {
+            if (serverURL == null || serverURL.startsWith("https")) {
                 protocol = "https://";
             } else {
                 protocol = "http://";
             }
-        } else if (serverURL != null ){
-            hostname = serverURL.substring(serverURL.indexOf("://")+3);
-            if(serverURL.startsWith("https")) {
+            serverURL = new StringAllocator(protocol).append(hostname).toString();
+        } else if (serverURL != null) {
+            hostname = serverURL.substring(serverURL.indexOf("://") + 3);
+            if (serverURL.startsWith("https")) {
                 protocol = "https://";
             } else {
                 protocol = "http://";
             }
         }
 
-
         final String otherDomain = config.getProperty(PROPERTY_USE_OTHER_DOMAIN);
         final String separateSubdomain = config.getProperty(PROPERTY_USE_OTHER_SUBDOMAIN);
 
-        if(otherDomain != null){
+        if (otherDomain != null) {
             return protocol + otherDomain;
         }
 
-        if(separateSubdomain != null){
-            return protocol + separateSubdomain + "." + hostname;
+        if (separateSubdomain != null) {
+            return new StringAllocator(protocol).append(separateSubdomain).append('.').append(hostname).toString();
         }
 
         return serverURL;
