@@ -59,7 +59,10 @@ import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 import java.util.Random;
+import java.util.regex.Matcher;
+import java.util.regex.Pattern;
 import org.json.JSONObject;
+import com.openexchange.context.ContextService;
 import com.openexchange.datatypes.genericonf.DynamicFormDescription;
 import com.openexchange.datatypes.genericonf.FormElement;
 import com.openexchange.exception.OXException;
@@ -179,16 +182,11 @@ public class OXMFPublicationService extends AbstractPublicationService {
             return templateService.loadTemplate(defaultTemplateName);
         }
         final String templateName = object.toString();
-        try {
-            if (templateName == null || "".equals(templateName)) {
-                return templateService.loadTemplate(defaultTemplateName);
-            }
-            final ServerSession serverSession = ServerSessionAdapter.valueOf(new PublicationSession(publication));
-            return templateService.loadTemplate(templateName, defaultTemplateName, serverSession);
-        } catch (final OXException e) {
-            throw e;
+        if (templateName == null || "".equals(templateName)) {
+            return templateService.loadTemplate(defaultTemplateName);
         }
-
+        final ServerSession serverSession = ServerSessionAdapter.valueOf(new PublicationSession(publication));
+        return templateService.loadTemplate(templateName, defaultTemplateName, serverSession);
     }
 
     @Override
@@ -324,4 +322,36 @@ public class OXMFPublicationService extends AbstractPublicationService {
         }
     }
 
+    @Override
+    public Publication resolveUrl(final ContextService service, String URL) throws OXException {
+        String re1=".*?";   // Non-greedy match on filler
+        String re2="("+rootURL+")";    // Word 1
+        String re3="(\\/)"; // Any Single Character 2
+        String re4="(\\d+)";    // Integer Number 1
+        String re5="(\\/)"; // Any Single Character 3
+        String re6="((?:[a-z][a-z]+))"; // Word 3
+        
+        Pattern p = Pattern.compile(re1+re2+re3+re4+re5+re6,Pattern.CASE_INSENSITIVE | Pattern.DOTALL);
+        Matcher m = p.matcher(URL);
+        if (m.find())
+        {
+            String contextId=m.group(3);
+            String site=m.group(5);
+            
+            final Context ctx = service.getContext(Integer.parseInt(contextId));
+            return getPublication(ctx, site);
+        }
+       
+        return null;
+    }
+
+    @Override
+    public String getInformation(Publication publication) {
+        StringBuilder sb = new StringBuilder();
+        sb.append("Publication:").append("/n");
+        sb.append("Context: " + publication.getContext().getContextId()).append("/n");
+        sb.append("UserID:  " + publication.getUserId()).append("/n");
+        return sb.toString();
+    }
+
 }
